@@ -9,6 +9,24 @@
 /*jsl:declare MP*/
 
 
+// Seems to fix many issues with columns in 4.2.1 grids
+// since we now cache all columns instead of just visible ones...
+// See http://www.sencha.com/forum/showthread.php?264959-4.2.1.833-Exception-when-editing-a-cell-of-previously-hidden-column
+
+Ext.define(MP.grid.ColumnManager, {
+    override: 'Ext.grid.ColumnManager',
+
+    cacheColumns: function()
+    {
+        this.columns = this.headerCt.getGridColumns();
+        if (this.secondHeaderCt)
+        {
+            Ext.Array.push(this.columns, this.secondHeaderCt.getGridColumns());
+        }
+    }
+});
+
+
 Ext.define('MP.grid.Editable', {
     extend: 'MP.grid.Basic',
 
